==> TFDEA_0.8.3.tar.gz: TFDEA/man/fighter_jet.Rd <==
\name{fighter_jet}
\alias{fighter_jet}
\docType{data}
\title{
Data: Fighter Jet technology forecasting data
}
\description{
Technical data from fighter jets for technology forecasting.
}
\usage{data(fighter_jet)}
\format{
  A data frame containing historical jet fighter data for technology forecasting.
  \describe{
    \item{\code{CruiseSpeed}}{a numeric vector}
    \item{\code{FirstFlight}}{a numeric vector}
    \item{\code{Guns}}{a numeric vector}
    \item{\code{InstantaneousTurnRate}}{a numeric vector}
    \item{\code{MaintenanceHoursPerFlightHour}}{a numeric vector}
    \item{\code{MaximumMachNumber}}{a numeric vector}
    \item{\code{MeanFlightHoursBetweenFailure}}{a numeric vector}
    \item{\code{Name}}{a numeric vector}
    \item{\code{NumberOfBVRMissiles}}{a numeric vector}
    \item{\code{NumberOfDogfightMissiles}}{a numeric vector}
    \item{\code{NumberOfSimultaneousTargets}}{a numeric vector}
    \item{\code{Payload}}{a numeric vector}
    \item{\code{RadarRange}}{a numeric vector}
    \item{\code{Range}}{a numeric vector}
    \item{\code{RangeOfBVRMissles}}{a numeric vector}
    \item{\code{RangeOfDogfightMissiles}}{a numeric vector}
    \item{\code{SeaLevelClimbRate}}{a numeric vector}
    \item{\code{SustainedTurnRate}}{a numeric vector}
    \item{\code{TakeoffRoll}}{a numeric vector}  
}}
%\details{
%%  ~~ If necessary, more details than the __description__ above ~~
%}
%\source{
%%  ~~ reference to a publication or URL from which the data were obtained ~~
%}
%\references{
%%  ~~ possibly secondary sources and usages ~~
%}
\examples{
data(fighter_jet)
}
\keyword{datasets}

==> TFDEA_0.9.4.tar.gz: TFDEA/man/fighter_jet.Rd <==
\name{fighter_jet}
\alias{fighter_jet}
\docType{data}
\title{
Data: Fighter Jet technology forecasting data
}
\description{
Technical data from fighter jets for technology forecasting.
}
\usage{data(fighter_jet)}
\format{
  A data frame containing historical jet fighter data for technology forecasting.
  \describe{
    \item{\code{CruiseSpeed}}{a numeric vector}
    \item{\code{FirstFlight}}{a numeric vector}
    \item{\code{Guns}}{a numeric vector}
    \item{\code{InstantaneousTurnRate}}{a numeric vector}
    \item{\code{MaintenanceHoursPerFlightHour}}{a numeric vector}
    \item{\code{MaximumMachNumber}}{a numeric vector}
    \item{\code{MeanFlightHoursBetweenFailure}}{a numeric vector}
    \item{\code{Name}}{a numeric vector}
    \item{\code{NumberOfBVRMissiles}}{a numeric vector}
    \item{\code{NumberOfDogfightMissiles}}{a numeric vector}
    \item{\code{NumberOfSimultaneousTargets}}{a numeric vector}
    \item{\code{Payload}}{a numeric vector}
    \item{\code{RadarRange}}{a numeric vector}
    \item{\code{Range}}{a numeric vector}
    \item{\code{RangeOfBVRMissiles}}{a numeric vector}
    \item{\code{RangeOfDogfightMissiles}}{a numeric vector}
    \item{\code{SeaLevelClimbRate}}{a numeric vector}
    \item{\code{SustainedTurnRate}}{a numeric vector}
    \item{\code{TakeoffRoll}}{a numeric vector}
}}
%\details{
%%  ~~ If necessary, more details than the __description__ above ~~
%}
%\source{
%%  ~~ reference to a publication or URL from which the data were obtained ~~
%}
%\references{
%%  ~~ possibly secondary sources and usages ~~
%}
\examples{
data(fighter_jet)
}
\keyword{datasets}
